@@ -8,8 +8,9 @@ class BaseDict(dict):
 
     def __init__(self, *args, **kwargs):
         if len(args) == 1 and isinstance(args[0], dict):
-            self._dict = args[0].dict() if issubclass(
-                type(args[0]), BaseDict) else args[0]
+            self._dict = (
+                args[0].dict() if issubclass(type(args[0]), BaseDict) else args[0]
+            )
             self._pointer = True
             super(BaseDict, self).__init__(self._dict)
             return
@@ -53,10 +54,6 @@ class BaseDict(dict):
             return len(self._dict)
         return super(BaseDict, self).__len__()
 
-    def __nonzero__(self):
-        # python 2
-        return self.__bool__()
-
     def __repr__(self):
         if self._pointer:
             return repr(self._dict)
@@ -73,11 +70,6 @@ class BaseDict(dict):
             return str(self._dict)
         return super(BaseDict, self).__str__()
 
-    def __unicode__(self):
-        if self._pointer:
-            return unicode(self._dict)
-        return '{}'.format(self)
-
     def clear(self):
         if self._pointer:
             self._dict.clear()
@@ -104,11 +96,6 @@ class BaseDict(dict):
             return self._dict.items()
         return super(BaseDict, self).items()
 
-    def iteritems(self):
-        if self._pointer:
-            return self._dict.iteritems()
-        return super(BaseDict, self).iteritems()
-
     def keys(self):
         if self._pointer:
             return self._dict.keys()
