@@ -6,7 +6,6 @@ from benedict.utils import type_util
 
 
 class IODict(BaseDict):
-
     def __init__(self, *args, **kwargs):
         """
         Constructs a new instance.
@@ -22,10 +21,10 @@ class IODict(BaseDict):
     @staticmethod
     def _decode_init(s, **kwargs):
         autodetected_format = io_util.autodetect_format(s)
-        default_format = autodetected_format or 'json'
-        format = kwargs.pop('format', default_format).lower()
-        if format in ['b64', 'base64']:
-            kwargs.setdefault('subformat', 'json')
+        default_format = autodetected_format or "json"
+        format = kwargs.pop("format", default_format).lower()
+        if format in ["b64", "base64"]:
+            kwargs.setdefault("subformat", "json")
         # decode data-string and initialize with dict data.
         return IODict._decode(s, format, **kwargs)
 
@@ -39,35 +38,35 @@ class IODict(BaseDict):
                 return data
             elif type_util.is_list(data):
                 # force list to dict
-                return {'values': data}
+                return {"values": data}
             else:
                 raise ValueError(
-                    'Invalid data type: {}, expected dict or list.'.format(
-                        type(data)))
+                    "Invalid data type: {}, expected dict or list.".format(type(data))
+                )
         except Exception as e:
             raise ValueError(
-                'Invalid data or url or filepath argument: {}\n{}'.format(
-                    s, e))
+                "Invalid data or url or filepath argument: {}\n{}".format(s, e)
+            )
 
     @staticmethod
     def _encode(d, format, **kwargs):
-        filepath = kwargs.pop('filepath', None)
+        filepath = kwargs.pop("filepath", None)
         s = io_util.encode(d, format, **kwargs)
         if filepath:
             io_util.write_file(filepath, s)
         return s
 
     @classmethod
-    def from_base64(cls, s, subformat='json', encoding='utf-8', **kwargs):
+    def from_base64(cls, s, subformat="json", encoding="utf-8", **kwargs):
         """
         Load and decode Base64 data from url, filepath or data-string.
         Data is decoded according to subformat and encoding.
         Decoder specific options can be passed using kwargs.
         Return a new dict instance. A ValueError is raised in case of failure.
         """
-        kwargs['subformat'] = subformat
-        kwargs['encoding'] = encoding
-        return cls(s, format='base64', **kwargs)
+        kwargs["subformat"] = subformat
+        kwargs["encoding"] = encoding
+        return cls(s, format="base64", **kwargs)
 
     @classmethod
     def from_csv(cls, s, columns=None, columns_row=True, **kwargs):
@@ -77,9 +76,9 @@ class IODict(BaseDict):
         https://docs.python.org/3/library/csv.html
         Return a new dict instance. A ValueError is raised in case of failure.
         """
-        kwargs['columns'] = columns
-        kwargs['columns_row'] = columns_row
-        return cls(s, format='csv', **kwargs)
+        kwargs["columns"] = columns
+        kwargs["columns_row"] = columns_row
+        return cls(s, format="csv", **kwargs)
 
     @classmethod
     def from_ini(cls, s, **kwargs):
@@ -89,7 +88,7 @@ class IODict(BaseDict):
         https://docs.python.org/3/library/configparser.html
         Return a new dict instance. A ValueError is raised in case of failure.
         """
-        return cls(s, format='ini', **kwargs)
+        return cls(s, format="ini", **kwargs)
 
     @classmethod
     def from_json(cls, s, **kwargs):
@@ -99,7 +98,7 @@ class IODict(BaseDict):
         https://docs.python.org/3/library/json.html
         Return a new dict instance. A ValueError is raised in case of failure.
         """
-        return cls(s, format='json', **kwargs)
+        return cls(s, format="json", **kwargs)
 
     @classmethod
     def from_pickle(cls, s, **kwargs):
@@ -109,7 +108,7 @@ class IODict(BaseDict):
         https://docs.python.org/3/library/pickle.html
         Return a new dict instance. A ValueError is raised in case of failure.
         """
-        return cls(s, format='pickle', **kwargs)
+        return cls(s, format="pickle", **kwargs)
 
     @classmethod
     def from_plist(cls, s, **kwargs):
@@ -119,7 +118,7 @@ class IODict(BaseDict):
         https://docs.python.org/3/library/plistlib.html
         Return a new dict instance. A ValueError is raised in case of failure.
         """
-        return cls(s, format='plist', **kwargs)
+        return cls(s, format="plist", **kwargs)
 
     @classmethod
     def from_query_string(cls, s, **kwargs):
@@ -127,7 +126,7 @@ class IODict(BaseDict):
         Load and decode query-string from url, filepath or data-string.
         Return a new dict instance. A ValueError is raised in case of failure.
         """
-        return cls(s, format='query_string', **kwargs)
+        return cls(s, format="query_string", **kwargs)
 
     @classmethod
     def from_toml(cls, s, **kwargs):
@@ -137,7 +136,7 @@ class IODict(BaseDict):
         https://pypi.org/project/toml/
         Return a new dict instance. A ValueError is raised in case of failure.
         """
-        return cls(s, format='toml', **kwargs)
+        return cls(s, format="toml", **kwargs)
 
     @classmethod
     def from_xml(cls, s, **kwargs):
@@ -147,7 +146,7 @@ class IODict(BaseDict):
         https://github.com/martinblech/xmltodict
         Return a new dict instance. A ValueError is raised in case of failure.
         """
-        return cls(s, format='xml', **kwargs)
+        return cls(s, format="xml", **kwargs)
 
     @classmethod
     def from_yaml(cls, s, **kwargs):
@@ -157,9 +156,9 @@ class IODict(BaseDict):
         https://pyyaml.org/wiki/PyYAMLDocumentation
         Return a new dict instance. A ValueError is raised in case of failure.
         """
-        return cls(s, format='yaml', **kwargs)
+        return cls(s, format="yaml", **kwargs)
 
-    def to_base64(self, subformat='json', encoding='utf-8', **kwargs):
+    def to_base64(self, subformat="json", encoding="utf-8", **kwargs):
         """
         Encode the current dict instance in Base64 format
         using the given subformat and encoding.
@@ -167,11 +166,11 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        kwargs['subformat'] = subformat
-        kwargs['encoding'] = encoding
-        return self._encode(self.dict(), 'base64', **kwargs)
+        kwargs["subformat"] = subformat
+        kwargs["encoding"] = encoding
+        return self._encode(self.dict(), "base64", **kwargs)
 
-    def to_csv(self, key='values', columns=None, columns_row=True, **kwargs):
+    def to_csv(self, key="values", columns=None, columns_row=True, **kwargs):
         """
         Encode a list of dicts in the current dict instance in CSV format.
         Encoder specific options can be passed using kwargs:
@@ -179,9 +178,9 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        kwargs['columns'] = columns
-        kwargs['columns_row'] = columns_row
-        return self._encode(self.dict()[key], 'csv', **kwargs)
+        kwargs["columns"] = columns
+        kwargs["columns_row"] = columns_row
+        return self._encode(self.dict()[key], "csv", **kwargs)
 
     def to_ini(self, **kwargs):
         """
@@ -191,7 +190,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), 'ini', **kwargs)
+        return self._encode(self.dict(), "ini", **kwargs)
 
     def to_json(self, **kwargs):
         """
@@ -201,7 +200,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), 'json', **kwargs)
+        return self._encode(self.dict(), "json", **kwargs)
 
     def to_pickle(self, **kwargs):
         """
@@ -212,7 +211,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), 'pickle', **kwargs)
+        return self._encode(self.dict(), "pickle", **kwargs)
 
     def to_plist(self, **kwargs):
         """
@@ -222,7 +221,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), 'plist', **kwargs)
+        return self._encode(self.dict(), "plist", **kwargs)
 
     def to_query_string(self, **kwargs):
         """
@@ -230,7 +229,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), 'query_string', **kwargs)
+        return self._encode(self.dict(), "query_string", **kwargs)
 
     def to_toml(self, **kwargs):
         """
@@ -240,7 +239,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), 'toml', **kwargs)
+        return self._encode(self.dict(), "toml", **kwargs)
 
     def to_xml(self, **kwargs):
         """
@@ -250,7 +249,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), 'xml', **kwargs)
+        return self._encode(self.dict(), "xml", **kwargs)
 
     def to_yaml(self, **kwargs):
         """
@@ -260,4 +259,4 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self.dict(), 'yaml', **kwargs)
+        return self._encode(self.dict(), "yaml", **kwargs)
