@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
 
 from benedict.serializers import (
-    get_format_by_path, get_serializer_by_format, get_serializers_extensions, )
+    get_format_by_path,
+    get_serializer_by_format,
+    get_serializers_extensions,
+)
 
 import fsutil
 
@@ -15,7 +18,7 @@ def autodetect_format(s):
 def decode(s, format, **kwargs):
     serializer = get_serializer_by_format(format)
     if not serializer:
-        raise ValueError('Invalid format: {}.'.format(format))
+        raise ValueError("Invalid format: {}.".format(format))
     decode_opts = kwargs.copy()
     data = serializer.decode(s.strip(), **decode_opts)
     return data
@@ -24,13 +27,13 @@ def decode(s, format, **kwargs):
 def encode(d, format, **kwargs):
     serializer = get_serializer_by_format(format)
     if not serializer:
-        raise ValueError('Invalid format: {}.'.format(format))
+        raise ValueError("Invalid format: {}.".format(format))
     s = serializer.encode(d, **kwargs)
     return s
 
 
 def is_data(s):
-    return (len(s.splitlines()) > 1)
+    return len(s.splitlines()) > 1
 
 
 def is_filepath(s):
@@ -40,8 +43,7 @@ def is_filepath(s):
 
 
 def is_url(s):
-    return any([s.startswith(protocol)
-                for protocol in ['http://', 'https://']])
+    return any([s.startswith(protocol) for protocol in ["http://", "https://"]])
 
 
 def read_content(s):
